This crate contains a trait that can be used to compose HTML pages.
This crate is designed to be used with HTMX, but it aims to be generic enough to be used with other frameworks or even alone. This crate is not affiliated to HTMX.
In this crate is defined the crate::render::Render trait, which can be used to define how an element is rendered as a string.
The module elements contains general-purpose, opinionated elements that can be used as-is or as examples for writing your custom elements. It can be enabled via feature flags.